@@ -5,7 +5,7 @@ use 5.008005;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 
@@ -31,7 +31,7 @@ John Napiorkowski C< <<jjnapiork@cpan.org>> >
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010, John Napiorkowski
+Copyright 2011, John Napiorkowski
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
@@ -60,7 +60,7 @@ template: |
   test_requires 'Test::More' => '0.96';
 
   require 'maint/Makefile.PL.include'
-    if $Module::Install::AUTHOR;
+    unless -e 'META.yml';
 
   WriteAll;
 ---
@@ -98,7 +98,7 @@ template: |
   
   =head1 COPYRIGHT & LICENSE
 
-  Copyright 2011, John Napiorkowski
+  Copyright 2011, [% config.author %] L<email:[% config.email %]> 
   
   This library is free software; you can redistribute it and/or modify
   it under the same terms as Perl itself.
@@ -110,45 +110,76 @@ template: |
   BEGIN {
     my @modules = qw(
       ReadmeMarkdownFromPod
-      ManifestSkip
       AutoLicense
       Repository
       Homepage
-      AutoManifest
     );
     for my $module (@modules) {
       eval "use Module::Install::$module; 1"
   	  || die <<"ERR";
-  
+
   You are in author mode but are missing Module::Install::$module
-  
+
   You are getting an error message because you are in author mode and are missing
   some author only dependencies.  You should only see this message if you have 
   checked this code out from a repository.  If you are just trying to install
   the code please use the CPAN version.  If you are an author you will need to
   install the missing modules, or you can bootstrap all the requirements using
   Task::BeLike::JJNAPIORK with:
-  
+
     cpanm Task::BeLike::JJNAPIORK
-  
+
   If you think you are seeing this this message in error, please report it as a
   bug to the author.
-  
+
   ERR
     }
   }
-  
+
   readme_markdown_from_pod;
-  manifest_skip;
   auto_license;
   auto_set_repository;
   auto_set_homepage;
-  auto_manifest;
   auto_install;
-  
+
+  sub manifest_include {
+    my @files = @_;
+    my @parts;
+    while (my ($dir, $spec) = splice(@files, 0, 2)) {
+      my $re = ($dir ? $dir.'/' : '').
+        ((ref($spec) eq 'Regexp')
+          ? $spec
+          : !ref($spec)
+            ? ".*\Q${spec}\E"
+            : die "spec must be string or regexp, was: ${spec} (${\ref $spec})");
+      push @parts, $re;
+    }
+    my $final = '^(?!'.join('|', map "${_}\$", @parts).')';
+    open(my $skip, '>', 'MANIFEST.SKIP') or die "trouble $!";
+    print $skip "${final}\n";
+    close $skip;
+  }
+
+  manifest_include(
+    'lib' => '.pm',
+    'inc' => '.pm',
+    't' => '.t',
+    't/lib' => '.pm',
+    'xt' => '.t',
+    'xt/lib' => '.pm',
+    'script' => qr{.pl|.psgi},
+    '' => qr{([^/]+).PL},
+    '' => qr{Changes|MANIFEST|README|META\.yml},
+  );
+
   postamble <<"EOP";
-  distclean :: manifest_skip_clean
-  
+  create_distdir: manifest_clean manifest
+
+  distclean :: manifest_clean manifest_skip_clean
+
+  manifest_clean:
+  \t\$(RM_F) MANIFEST
+
   manifest_skip_clean:
   \t\$(RM_F) MANIFEST.SKIP
   EOP
